@@ -16,7 +16,7 @@ DEFAULT_CONFIGFILE = ospath.join(
 
 _UNSET = object()
 _FILENAMESRE = re.compile(
-    r'(?P<DOCTYPE>[^_]+)_(?P<YEAR>'
+    r'(?P<DOCTYPE>[A-Za-z_-_]+)_(?P<YEAR>'
     r'[0-9]+)_(?P<MONTH>[^_]+)\.pdf',
     re.IGNORECASE
 )
@@ -36,7 +36,7 @@ class Config(object):
         'outline': {
             'no_entr_name': False
         },
-        'preprocessor': {'payroll': 'endi-split-pdf-page2text'},
+        'preprocessor': 'endi-split-pdf-page2text',
         'restrict': 0,
         'mail': {'subject': '[%(hostname)s] Log of endi pdf splitter', },
         'pb_dir': os.path.join(os.environ['HOME'], 'problems'),
